<?php

namespace Drupal\mapbox_ui\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class mapBoxConfigForm.
 *
 * @internal
 */
class MapBoxConfigForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'mapbox_config_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildForm($form, $form_state);
    $config = $this->config('mapbox.settings');
    $form['accessToken'] = [
      '#type' => 'textfield',
      '#title' => $this->t('AccessToken'),
      '#default_value' => $config->get('mapbox.accessToken'),
      '#required' => TRUE,
    ];
    $form['style'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Style'),
      '#default_value' => $config->get('mapbox.style'),
      '#required' => TRUE,
    ];
    $form['center'] = [
      '#type' => 'fieldset',
      '#title' => t('Center'),
    ];
    $form['center']['altitude'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Altitude'),
      '#default_value' => $config->get('mapbox.altitude'),
    ];
    $form['center']['latitude'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Latitude'),
      '#default_value' => $config->get('mapbox.latitude'),
    ];
    $form['marker'] = [
      '#type' => 'fieldset',
      '#title' => t('Marker'),
    ];
    $form['marker']['marker_altitude'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Altitude'),
      '#default_value' => $config->get('mapbox.marker_altitude'),
    ];
    $form['marker']['marker_latitude'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Latitude'),
      '#default_value' => $config->get('mapbox.marker_latitude'),
    ];
    $form['popup_texte'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Marker description'),
      '#default_value' => $config->get('mapbox.popup_texte'),
    ];
    $form['zoom'] = [
      '#type' => 'number',
      '#title' => $this->t('Zoom'),
      '#default_value' => $config->get('mapbox.zoom'),
    ];
    $form['navigationcontrol'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Active Navigation Control'),
      '#default_value' => $config->get('mapbox.navigationcontrol'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('mapbox.settings');
    $config->set('mapbox.accessToken', $form_state->getValue('accessToken'));
    $config->set('mapbox.style', $form_state->getValue('style'));
    $config->set('mapbox.altitude', $form_state->getValue('altitude'));
    $config->set('mapbox.latitude', $form_state->getValue('latitude'));
    $config->set('mapbox.marker_altitude', $form_state->getValue('marker_altitude'));
    $config->set('mapbox.marker_latitude', $form_state->getValue('marker_latitude'));
    $config->set('mapbox.popup_texte', $form_state->getValue('popup_texte'));
    $config->set('mapbox.zoom', $form_state->getValue('zoom'));
    $config->set('mapbox.navigationcontrol', $form_state->getValue('navigationcontrol'));
    $config->save();
    return parent::submitForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'mapbox.settings',
    ];
  }

}
