<?php

namespace Drupal\mapbox_ui\Plugin\Block;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Block\BlockBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Session\AccountInterface;

/**
 * Provides a block with a simple text.
 *
 * @Block(
 *   id = "mapbox_ui_block",
 *   admin_label = @Translation("Mapbox block"),
 * )
 */
class MapBoxBlock extends BlockBase {

  /**
   * {@inheritdoc}
   */
  public function build() {
    $build = [];

    $config = \Drupal::config('mapbox.settings');
    $build['#theme'] = 'mapbox_ui_block';
    $build['#attached']['library'][] = 'mapbox_ui/mapbox_ui';
    $build['#attached']['drupalSettings']['mapBoxBlock']['accessToken'] = $config->get('mapbox.accessToken');
    $build['#attached']['drupalSettings']['mapBoxBlock']['style'] = $config->get('mapbox.style');
    $build['#attached']['drupalSettings']['mapBoxBlock']['center']['altitude'] = $config->get('mapbox.altitude');
    $build['#attached']['drupalSettings']['mapBoxBlock']['center']['latitude'] = $config->get('mapbox.latitude');
    $build['#attached']['drupalSettings']['mapBoxBlock']['marker']['marker_altitude'] = $config->get('mapbox.marker_altitude');
    $build['#attached']['drupalSettings']['mapBoxBlock']['marker']['marker_latitude'] = $config->get('mapbox.marker_latitude');
    $build['#attached']['drupalSettings']['mapBoxBlock']['popup_texte'] = $config->get('mapbox.popup_texte');
    $build['#attached']['drupalSettings']['mapBoxBlock']['zoom'] = $config->get('mapbox.zoom');
    $build['#attached']['drupalSettings']['mapBoxBlock']['navigationcontrol'] = $config->get('mapbox.navigationcontrol');

    return $build;
  }

  /**
   * {@inheritdoc}
   */
  protected function blockAccess(AccountInterface $account) {
    return AccessResult::allowedIfHasPermission($account, 'access content');
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $config = $this->getConfiguration();
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    $this->configuration['mapbox_settings'] = $form_state->getValue('mapbox_settings');
  }

}
